summaryrefslogtreecommitdiff
path: root/framework/source/jobs/jobdata.cxx
diff options
context:
space:
mode:
authorThomas Arnhold <thomas@arnhold.org>2013-04-15 04:49:39 +0200
committerThomas Arnhold <thomas@arnhold.org>2013-04-15 04:49:39 +0200
commit60fbefc615f8931bf8b952293fc4eb4ac35dafd8 (patch)
tree2a91fcbcb206d60dcc652a336bb9b6813578815e /framework/source/jobs/jobdata.cxx
parent7f71ed1c62775a4e5b2efebf55f284a5c32b2df4 (diff)
fdo#60724 informations -> information
Change-Id: Ifd34ebfc7fe01b4a470eb072597dd3ec97c97863
Diffstat (limited to 'framework/source/jobs/jobdata.cxx')
-rw-r--r--framework/source/jobs/jobdata.cxx14
1 files changed, 7 insertions, 7 deletions
diff --git a/framework/source/jobs/jobdata.cxx b/framework/source/jobs/jobdata.cxx
index fa1633472efd..a39114d82a7c 100644
--- a/framework/source/jobs/jobdata.cxx
+++ b/framework/source/jobs/jobdata.cxx
@@ -139,7 +139,7 @@ JobData::~JobData()
/**
@short initalize this instance as a job with configuration
@descr They given alias can be used to address some configuraton data.
- We read it and fill our internal structures. Of course old informations
+ We read it and fill our internal structures. Of course old information
will be lost doing so.
@param sAlias
@@ -149,10 +149,10 @@ void JobData::setAlias( const OUString& sAlias )
{
/* SAFE { */
WriteGuard aWriteLock(m_aLock);
// delete all old informations! Otherwhise we mix it with the new one ...
impl_reset();
// take over the new informations
m_sAlias = sAlias;
m_eMode = E_ALIAS;
@@ -209,7 +209,7 @@ void JobData::setAlias( const OUString& sAlias )
//________________________________
/**
@short initalize this instance as a job without configuration
- @descr This job has no configuration data. We have to forget all old informations
+ @descr This job has no configuration data. We have to forget all old information
and set only some of them new, so this instance can work.
@param sService
@@ -220,9 +220,9 @@ void JobData::setService( const OUString& sService )
/* SAFE { */
WriteGuard aWriteLock(m_aLock);
// delete all old informations! Otherwhise we mix it with the new one ...
impl_reset();
// take over the new informations
m_sService = sService;
m_eMode = E_SERVICE;
@@ -698,7 +698,7 @@ css::uno::Sequence< OUString > JobData::getEnabledJobsForEvent( const css::uno::
@short reset all internal structures
@descr If somehwere recycle this instance, he can switch from one
using mode to another one. But then we have to reset all currently
- used informations. Otherwhise we mix it and they can make trouble.
+ used information. Otherwhise we mix it and they can make trouble.
But note: that does not set defaults for internal used members, which
does not relate to any job property! e.g. the reference to the global
@@ -149,10 +149,10 @@ void JobData::setAlias( const OUString& sAlias )
/* SAFE { */
WriteGuard aWriteLock(m_aLock);
- // delete all old informations! Otherwhise we mix it with the new one ...
+ // delete all old information! Otherwhise we mix it with the new one ...
impl_reset();
@@ -149,10 +149,10 @@ void JobData::setAlias( const OUString& sAlias )
impl_reset();
- // take over the new informations
+ // take over the new information
m_sAlias = sAlias;
m_eMode = E_ALIAS;
@@ -220,9 +220,9 @@ void JobData::setService( const OUString& sService )
/* SAFE { */
WriteGuard aWriteLock(m_aLock);
- // delete all old informations! Otherwhise we mix it with the new one ...
+ // delete all old information! Otherwhise we mix it with the new one ...
impl_reset();
@@ -220,9 +220,9 @@ void JobData::setService( const OUString& sService )
impl_reset();
- // take over the new informations
+ // take over the new information
m_sService = sService;
m_eMode = E_SERVICE;